==> qtjambi-quick-debuginfo-macos-6.5.3.jar: sources/QtJambiQuick/QSGVulkanTexture_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsgtexture_platform.h>
#include <QtCore/QVariant>
#include <QtQuick/qsgtexture.h>
#include <QtQuick/qquickwindow.h>
#include <QtCore/qsize.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(vulkan)


// emitting (writeClassCodeInjections)
QSGTexture * qtjambi_QSGVulkanTexture_fromNative(JNIEnv *env, jlong image, jint layout, QQuickWindow* window, const QSize& size, QQuickWindow::CreateTextureOptions options);


#endif // QT_CONFIG(vulkan)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGVulkanTexture::nativeImage()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGVulkanTexture_00024Impl_00024ConcreteWrapper_nativeImage_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(vulkan)
        const QNativeInterface::QSGVulkanTexture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGVulkanTexture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGVulkanTexture::nativeImage()const", __qt_this)
        VkImage __qt_return_value = __qt_this->nativeImage();
        __java_return_value = jlong(__qt_return_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(vulkan)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGVulkanTexture::nativeImageLayout()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGVulkanTexture_00024Impl_00024ConcreteWrapper_nativeImageLayout_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(vulkan)
        const QNativeInterface::QSGVulkanTexture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGVulkanTexture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGVulkanTexture::nativeImageLayout()const", __qt_this)
        VkImageLayout __qt_return_value = __qt_this->nativeImageLayout();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(vulkan)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGVulkanTexture::fromNative(VkImage,VkImageLayout,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGVulkanTexture_00024Impl_fromNative_1native_1VkImage_1VkImageLayout_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__JIJJI)
(JNIEnv *__jni_env,
 jclass,
 jlong image0,
 jint layout1,
 QtJambiNativeID window2,
 QtJambiNativeID size3,
 jint options4)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGVulkanTexture::fromNative(VkImage,VkImageLayout,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(vulkan)
#ifdef __qt_image0
#undef __qt_image0
#endif
#define __qt_image0 image0
#ifdef __qt_layout1
#undef __qt_layout1
#endif
#define __qt_layout1 layout1
        QQuickWindow* __qt_window2 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window2);
        const QSize& __qt_size3 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size3);
        QQuickWindow::CreateTextureOptions __qt_options4 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options4);
        auto __qt_return_value = qtjambi_QSGVulkanTexture_fromNative(__jni_env, __qt_image0, __qt_layout1, __qt_window2, __qt_size3, QQuickWindow::CreateTextureOptions(__qt_options4));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(image0)
        Q_UNUSED(layout1)
        Q_UNUSED(window2)
        Q_UNUSED(size3)
        Q_UNUSED(options4)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(vulkan)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGVulkanTexture(){
    using namespace RegistryAPI;

#if QT_CONFIG(vulkan)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGVulkanTexture>("QNativeInterface::QSGVulkanTexture", "io/qt/quick/nativeinterface/QSGVulkanTexture");
    registerNativeInterface<QNativeInterface::QSGVulkanTexture>("io/qt/quick/nativeinterface/QSGVulkanTexture");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGVulkanTexture* _object = dynamic_cast<QNativeInterface::QSGVulkanTexture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGVulkanTexture *object = reinterpret_cast<QNativeInterface::QSGVulkanTexture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGVulkanTexture *object = reinterpret_cast<const QNativeInterface::QSGVulkanTexture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(vulkan)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGVulkanTexture", {});

#endif //QT_CONFIG(vulkan)

}

==> qtjambi-quick-debuginfo-macos-6.5.7.jar: sources/QtJambiQuick/QSGVulkanTexture_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtQuick/qsgtexture_platform.h>)
#include <QtQuick/qsgtexture_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#if __has_include(<QtGui/qvulkaninstance.h>)
#include <QtGui/qvulkaninstance.h>
#endif
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(vulkan)


// emitting (writeClassCodeInjections)
QSGTexture * qtjambi_QSGVulkanTexture_fromNative(JNIEnv *env, jlong image, jint layout, QQuickWindow* window, const QSize& size, QQuickWindow::CreateTextureOptions options);


#endif // QT_CONFIG(vulkan)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGVulkanTexture::nativeImage()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGVulkanTexture_00024Impl_00024ConcreteWrapper_nativeImage_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(vulkan)
        const QNativeInterface::QSGVulkanTexture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGVulkanTexture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGVulkanTexture::nativeImage()const", __this_nativeId)
        VkImage __qt_return_value = __qt_this->nativeImage();
        __java_return_value = jlong(__qt_return_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(vulkan)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGVulkanTexture::nativeImageLayout()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGVulkanTexture_00024Impl_00024ConcreteWrapper_nativeImageLayout_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(vulkan)
        const QNativeInterface::QSGVulkanTexture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGVulkanTexture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGVulkanTexture::nativeImageLayout()const", __this_nativeId)
        VkImageLayout __qt_return_value = __qt_this->nativeImageLayout();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(vulkan)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGVulkanTexture::fromNative(VkImage,VkImageLayout,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGVulkanTexture_00024Impl_fromNative_1native_1VkImage_1VkImageLayout_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__JIJJI)
(JNIEnv *__jni_env,
 jclass,
 jlong image0,
 jint layout1,
 QtJambiNativeID window2,
 QtJambiNativeID size3,
 jint options4)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGVulkanTexture::fromNative(VkImage,VkImageLayout,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(vulkan)
#ifdef __qt_image0
#undef __qt_image0
#endif
#define __qt_image0 image0
#ifdef __qt_layout1
#undef __qt_layout1
#endif
#define __qt_layout1 layout1
        QQuickWindow* __qt_window2 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window2);
        const QSize& __qt_size3 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size3);
        QQuickWindow::CreateTextureOptions __qt_options4 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options4);
        auto __qt_return_value = qtjambi_QSGVulkanTexture_fromNative(__jni_env, __qt_image0, __qt_layout1, __qt_window2, __qt_size3, QQuickWindow::CreateTextureOptions(__qt_options4));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(image0)
        Q_UNUSED(layout1)
        Q_UNUSED(window2)
        Q_UNUSED(size3)
        Q_UNUSED(options4)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(vulkan)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGVulkanTexture(){
    using namespace RegistryAPI;

#if QT_CONFIG(vulkan)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGVulkanTexture>("QNativeInterface::QSGVulkanTexture", "io/qt/quick/nativeinterface/QSGVulkanTexture");
    registerNativeInterface<QNativeInterface::QSGVulkanTexture>("io/qt/quick/nativeinterface/QSGVulkanTexture");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGVulkanTexture* _object = dynamic_cast<QNativeInterface::QSGVulkanTexture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGVulkanTexture *object = reinterpret_cast<QNativeInterface::QSGVulkanTexture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGVulkanTexture *object = reinterpret_cast<const QNativeInterface::QSGVulkanTexture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(vulkan)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGVulkanTexture", {});

#endif //QT_CONFIG(vulkan)

}
